@@ -32,8 +32,6 @@ class {package_name}Conan(Sense2File):
     default_options = {{"shared": False, "fPIC": True}}
     generators = "cmake"
     requires = ""
-    # docker_version = "<dokcer version>"
-    # sense_system_deb = "<debs>"
     
     ## make deb setting
     deb_control = {{
@@ -50,13 +48,13 @@ class {package_name}Conan(Sense2File):
     }}
     changelog = "my changelog test"
     
-    ### upload cpp package to artifactory
+    ## user and channel for uploading cpp package to artifactory
     # user="user"
     # channel="beta"
 
     ## upload deb setting
     apt_user = "qiuhai"
-    apt_sever = "http://10.0.50.109:8081/repository/sense2-system-deb/"
+    apt_server = "http://10.0.50.109:8081/repository/sense2-system-deb/"
     
     ## set source at the same folder with recipe
     exports_sources = "*"
