@@ -32,7 +32,7 @@ class CmdUploadDeb(CmdUpload):
             cpu_count() if parallel_upload else 1)
 
         for remote, refs in refs_by_remote.items():
-            self._output.info("Uploading to remote '{}':".format(remote.name))
+            # self._output.info("Uploading to remote '{}':".format(remote.name))
 
             def upload_ref(ref_conanfile_prefs):
                 _ref, _conanfile, _prefs = ref_conanfile_prefs
@@ -72,8 +72,8 @@ class CmdUploadDeb(CmdUpload):
         # FIXME: because the recipe can have one and the package a different one
         self._hook_manager.execute("pre_upload", conanfile_path=conanfile_path,
                                    reference=ref, remote=recipe_remote)
-        msg = "\rUploading %s to remote '%s'" % (str(ref), recipe_remote.name)
-        self._output.info(left_justify_message(msg))
+        # msg = "\rUploading %s to remote '%s'" % (str(ref), recipe_remote.name)
+        # self._output.info(left_justify_message(msg))
        
         # Now the binaries
         if prefs:
@@ -83,10 +83,10 @@ class CmdUploadDeb(CmdUpload):
             def upload_package_index(index_pref):
                 index, pref = index_pref
                 try:
-                    up_msg = "\rUploading package %d/%d: %s to '%s'" % (index + 1, total,
-                                                                        str(pref.id),
-                                                                        p_remote.name)
-                    self._output.info(left_justify_message(up_msg))
+                    # up_msg = "\rUploading package %d/%d: %s to '%s'" % (index + 1, total,
+                    #                                                     str(pref.id),
+                    #                                                     p_remote.name)
+                    # self._output.info(left_justify_message(up_msg))
                     self._upload_deb(pref, retry, retry_wait, integrity_check, policy, p_remote)
                     # upload_recorder.add_package(pref, p_remote.name, p_remote.url)
                 except BaseException as pkg_exc:
@@ -119,7 +119,7 @@ class CmdUploadDeb(CmdUpload):
 
         assert (pref.revision is not None), "Cannot upload a package without PREV"
         assert (pref.ref.revision is not None), "Cannot upload a package without RREV"
-
+        
         pkg_layout = self._cache.package_layout(pref.ref)
         conanfile_path = pkg_layout.conanfile()
         package_fold = pkg_layout.package(pref)
@@ -127,11 +127,18 @@ class CmdUploadDeb(CmdUpload):
         
         deb_folder = pkg_layout.deb(pref)
         deb_file = os.path.join(deb_folder, conanfile.name + "_" + conanfile.version + ".deb")
+
+        if conanfile.apt_server == "":
+            self._output.error("apt_server is not defined in conanfile.")
+            return pref
+        
+        msg = "\rUploading %s to remote '%s'" % (str(pref.ref), conanfile.apt_server)
+        self._output.info(left_justify_message(msg))
         
         if os.path.exists(deb_file):
             # upload deb file
             upload_deb_cmd = 'ret=$(curl -u "'+ conanfile.apt_user +'" -H "Content-Type: multipart/form-data" --data-binary "@' \
-                                + deb_file + '" "' + conanfile.apt_sever + '" -f)'
+                                + deb_file + '" "' + conanfile.apt_server + '" -f)'
             conanfile.run(upload_deb_cmd)
         else:
             print("Warning: deb file is not exist")
