@@ -32,3 +32,21 @@ class Sense2File(ConanFile):
     
     def upload_deb(sef):
         pass
+
+def parseRequires2Denpens(requires):
+
+    deps = []
+    import re
+    if isinstance(requires, str):
+        dep = re.split('[/@]', requires)
+        if len(dep) >= 2:
+            deps.append(dep[0] + "(>=" + dep[1] + ")")
+
+    elif isinstance(requires, tuple) or isinstance(requires, list):
+        for req in requires:
+            dep = re.split('[/@]', req)  
+            if len(dep) >= 2:
+                deps.append(dep[0] + "(>=" + dep[1] + ")")
+                
+    deps_str = ','.join(deps)
+    return deps_str
\ No newline at end of file
